@@ -4,7 +4,12 @@
 # linear model for clustered data
 glm.cluster <- function( data , formula , cluster , ... ){
 	mod <- glm( data=data , formula=formula ,  ... )
-	dfr <- data.frame( "idschool" = data[ , cluster ] ) 
+	if ( length(cluster) > 1 ){
+			v1 <- cluster 
+				} else {
+			v1 <- data[,cluster]
+						}	
+	dfr <- data.frame( cluster = v1 ) 
 	vcov2 <- multiwayvcov::cluster.vcov( model = mod , cluster = dfr)	
 	res <- list( "glm_res" = mod , "vcov" = vcov2 )
 	class(res) <- "glm.cluster"
